CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
74 lines
2.2 KiB
C++
74 lines
2.2 KiB
C++
// Copyright Advanced Micro Devices, Inc., or its affiliates.
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
#ifdef ROCROLLER_USE_HIP
|
|
#include <hip/hip_ext.h>
|
|
#include <hip/hip_runtime.h>
|
|
#endif /* ROCROLLER_USE_HIP */
|
|
|
|
#include <common/CommonGraphs.hpp>
|
|
|
|
#include "GPUContextFixture.hpp"
|
|
|
|
using namespace rocRoller;
|
|
|
|
namespace StreamTest
|
|
{
|
|
|
|
class StreamTest : public CurrentGPUContextFixture
|
|
{
|
|
void SetUp() override
|
|
{
|
|
CurrentGPUContextFixture::SetUp();
|
|
}
|
|
};
|
|
|
|
TEST_F(StreamTest, AsyncStream)
|
|
{
|
|
auto const nx = 4096;
|
|
|
|
RandomGenerator random(31415u);
|
|
|
|
auto a = random.vector<int>(nx, -100, 100);
|
|
auto b = random.vector<int>(nx, -100, 100);
|
|
|
|
auto d_a = make_shared_device(a);
|
|
auto d_b = make_shared_device(b);
|
|
auto d_c = make_shared_device<int>(nx);
|
|
auto d_alpha = make_shared_device<int>();
|
|
|
|
int alpha = 22;
|
|
|
|
std::vector<int> r(nx);
|
|
|
|
ASSERT_THAT(hipMemcpy(d_alpha.get(), &alpha, 1 * sizeof(int), hipMemcpyDefault),
|
|
HasHipSuccess(0));
|
|
|
|
auto vectorAdd = rocRollerTest::Graphs::VectorAdd<int>();
|
|
|
|
CommandKernel commandKernel(vectorAdd.getCommand(), "VectorAdd");
|
|
commandKernel.setContext(m_context);
|
|
commandKernel.generateKernel();
|
|
|
|
auto runtimeArgs
|
|
= vectorAdd.getRuntimeArguments(nx, d_alpha.get(), d_a.get(), d_b.get(), d_c.get());
|
|
|
|
// Launch the kernel on a new stream instead of the default one
|
|
hipStream_t stream;
|
|
ASSERT_THAT(hipStreamCreate(&stream), HasHipSuccess(0));
|
|
|
|
commandKernel.launchKernel(runtimeArgs.runtimeArguments(), stream);
|
|
|
|
ASSERT_THAT(hipStreamSynchronize(stream), HasHipSuccess(0));
|
|
ASSERT_THAT(hipMemcpy(r.data(), d_c.get(), nx * sizeof(int), hipMemcpyDefault),
|
|
HasHipSuccess(0));
|
|
|
|
// reference solution
|
|
auto tol = AcceptableError{5 * std::sqrt(nx) * epsilon<double>(), "Sqrt(N) * epsilon"};
|
|
auto res = compare(r, vectorAdd.referenceSolution(alpha, a, b), tol);
|
|
EXPECT_TRUE(res.ok) << res.message();
|
|
|
|
ASSERT_THAT(hipStreamDestroy(stream), HasHipSuccess(0));
|
|
}
|
|
}
|